@@ -28,7 +28,17 @@ def parser_swagger(func, desc):
     elif type(func).__name__ == "function":
         default_args = get_default_args(func)
         type_args = get_type_args(func)
-        param_list = []
+        param_list = [{
+            "name": "User",
+            "in": "header",
+            "required": False,
+            "type": "object"
+        }, {
+            "name": "Authorization",
+            "in": "header",
+            "required": False,
+            "type": "string"
+        }]
         func_params = func.__code__.co_varnames
         if func.__http_method__ == "get":
             for i in range(1, func.__code__.co_argcount):
@@ -83,15 +93,17 @@ def parser_swagger(func, desc):
                         }
                     }
 
-            param = {
-                "required": True,
-                "name": "body",
-                "in": "body",
-                "schema": schema
-            }
+            param_list.append(
+                {
+                    "required": True,
+                    "name": "body",
+                    "in": "body",
+                    "schema": schema
+                }
+            )
             swagger_json_class.append({
                 "route": func.__route_name__,
-                "parameters": [param],
+                "parameters": param_list,
                 "description": desc,
                 "http_method": func.__http_method__
             })
